/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 *
 * (C) 2009,
 * @author JBoss Inc.
 */
package org.jboss.jbossts.qa.junit;

import org.junit.Before;
import org.junit.After;
import org.junit.Assert;

import java.io.*;

/**
 * Base class from which all autogenerated test suites inherit common behaviour.
 *
 * @author Jonathan Halliday (jonathan.halliday@redhat.com) 2009-05
 */

public class TestGroupBase {

    @Before public void setUp()
	{
        // no need to do this here as it gets done in tearDown
        // TaskImpl.cleanupTasks();
        // TODO EmptyObjectStore
	}

	@After public void tearDown()
	{
        TaskImpl.cleanupTasks();
    }

    public Task createTask(Class clazz, Task.TaskType taskType) {
        return new TaskImpl(clazz, taskType);
    }

    public Task createTask(Class clazz, Task.TaskType taskType, String filename, int timeout) {
        OutputStream out;
        try {
            File outFile = new File(filename);
            if (outFile.isDirectory()) {
                Assert.fail("createTask : output file name identifies directory " + filename);
            }
            File directory = outFile.getParentFile();
            if (!directory.exists() && !directory.mkdirs()) {
                Assert.fail("createTask : could not create directory for file " + filename);
            }
            out = new FileOutputStream(outFile);

            return new TaskImpl(clazz, taskType, new PrintStream(out, true), timeout);
        } catch (Exception e) {
            e.printStackTrace();
            Assert.fail("createTask : could not open output stream for file " + filename);
            return null;
        }
    }
}
